@@ -32,7 +32,7 @@ class BarProvider:
         self._is_supplement_blank_bar: bool = False
         self._enable_live: bool = False
         self._change_state = 0  # 0-没有barOpen,barClose,有更新;1-barClose;2-barOpen;3-barClose/barOpen;4-没有更新
-        self._instrument_id: string = ""
+        self.instrument_id: string = ""
         self._interval: int = 0
         self.bar_type: EnumBarType = EnumBarType.minute
         self._handlers: defaultdict = defaultdict(list)  # 暂时先不用，后面有需求再放开，通过线程来处理事件，参考vn.py
@@ -71,7 +71,7 @@ class BarProvider:
         :param bar_type:
         :param instrument_ids:
         """
-        self._instrument_id = instrument_id
+        self.instrument_id = instrument_id
         self._interval = interval
         self.bar_type = bar_type
         if (bar_type == EnumBarType.second) | (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
@@ -91,7 +91,7 @@ class BarProvider:
         :param bar_type:
         :param instrument_ids:
         """
-        self._instrument_id = instrument_id
+        self.instrument_id = instrument_id
         self._interval = interval
         self.bar_type = bar_type
         self._lst_date_time_slices = BaseBarHelper.create_one_day_date_time_slice(instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
@@ -107,7 +107,7 @@ class BarProvider:
         :param bar_type:
         :param instrument_ids:
         """
-        self._instrument_id = instrument_id
+        self.instrument_id = instrument_id
         self._interval = interval
         self.bar_type = bar_type
         if (bar_type == EnumBarType.second) | (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
@@ -147,7 +147,7 @@ class BarProvider:
         :param end_date:
         :param instrument_ids:
         """
-        self._instrument_id = instrument_id
+        self.instrument_id = instrument_id
         self._interval = 1
         self.bar_type = EnumBarType.hour
         self._lst_date_time_slices = BaseBarHelper.create_night_am_pm_date_time_slice_by_date(instrument_manager, instrument_id, begin_date, end_date, *instrument_ids)
