@@ -943,6 +943,47 @@ class QiDataController:
 
         return bar_provider.bar_series
 
+    def get_bar_series(self, market, instrument_id, interval, bar_type, end_time, bar_series, restore=EnumRestoration.不复权, *instrument_ids):
+        """
+        实盘根据回溯根数获取K线
+        历史K线从历史数据直接加载组装
+        当日K线根据Tick数据组装
+        最后合并历史和当日K线，并返回
+        注意：
+        若之前已经获取过品种的K线数据，则直接从缓存返回K线，(判断条件：interval，bar_type的唯一性)
+        若之前没有获取过品种的K线数据，则加载K线数据到缓存，并返回
+        :param market:市场
+        :param instrument_id:合约编号
+        :param interval:间隔
+        :param bar_type:K线类型
+        :param end_time:截止时间
+        :param restore:复权方式
+        :param instrument_ids:参与求交易时间交集的品种
+        :return:
+        """
+        bar_providers = []
+        if instrument_id in self.__bar_series_map.keys():
+            bar_providers = self.__bar_series_map[instrument_id]
+        else:
+            self.__bar_series_map[instrument_id] = bar_providers
+
+        # 已经获取过直接返回
+        if len(bar_providers) > 0:
+            bar_provider = next((data for data in bar_providers if (data.interval == interval) & (data.bar_type == bar_type)), None)
+            if bar_provider is not None:
+                return bar_provider.bar_series
+
+        bar_provider = BarProvider()
+        bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, self.trading_day, interval, bar_type, *instrument_ids)
+        for bar in bar_series:
+            bar_provider.bar_series.append(bar)
+
+        # 组装当日数据
+        self.__combine_today_tick(bar_provider, market, end_time)
+
+        bar_providers.append(bar_provider)
+        return bar_provider.bar_series
+
     def __combine_today_tick(self, bar_provider, market, end_time):
         date_time_slice = self.instrument_manager.get_living_date_time(self.trading_day, bar_provider.instrument_id)
         if end_time > date_time_slice.begin_time:
@@ -953,7 +994,7 @@ class QiDataController:
                 for tick in tick_series:
                     if tick.date_time <= end_time:
                         bar_provider.add_tick(tick)
-                        if tick.date_time == date_time_slice.BeginTime:  # 第1个的Tick包含集合竞价信息, 特殊处理
+                        if tick.date_time == date_time_slice.begin_time:  # 第1个的Tick包含集合竞价信息, 特殊处理
                             bar_provider.bar_series[-1].high = tick.high_price
                             bar_provider.bar_series[-1].open = tick.open_price
                             bar_provider.bar_series[-1].low = tick.low_price
