@@ -582,7 +582,7 @@ class OldStrategy:
         self.lst_summary = [
             [self.drive_code, self.start_simulate_date, self.end_simulate_date, self.trading_day_num, self.total_trade_lots, self.volume_per_day,
              self.total_yield_rate, self.annual_yield_rate, self.profit_per_hand, self.max_retrace, self.max_retrace_rate, self.retrace_ratio, self.sharpe_ratio,
-             self.max_daily_loss, self.continuous_innovation_high_days, self.max_loss_days]]
+             self.max_daily_loss, self.continuous_innovation_high_days, self.max_daily_loss]]
         self.df_summary = pd.DataFrame(self.lst_summary, columns=['品种', '开始日期', '截止日期', '交易天数', '总手数', '日均手数',
                                                                   '总收益', '年化收益', '每手盈利', '最大回撤值', '最大回撤', '收益回撤比', '夏普率',
                                                                   '单日最大亏损', '连续不创新高天数', '最大连续亏损天数'])
